#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_PREV_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_PREV_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/scalar/prev.hpp>

#endif
